@@ -7,9 +7,6 @@ use warnings;
 
 use Carp;
 
-use Data::Dumper ();
-use Types::Standard ();
-
 use Exporter qw(import);
 use Scalar::Util qw(blessed looks_like_number reftype);
 
@@ -21,6 +18,7 @@ our @EXPORT_OK = qw(
     data_hash
     data_integer
     data_number
+    data_regexp
     data_scalar
     data_string
     data_undef
@@ -43,7 +41,7 @@ our @EXPORT_OK = qw(
     type_universal
 );
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 sub codify ($) {
     my $code = shift;
@@ -51,11 +49,7 @@ sub codify ($) {
     my $body = sprintf 'sub { %s do { %s } }', $vars, $code // 'return(@_)';
 
     my $sub;
-    my $error = do {
-        local $@;
-        $sub = eval $body;
-        $@;
-    };
+    my $error = do { local $@; $sub = eval $body; $@ };
 
     croak $error unless $sub;
     return $sub;
@@ -108,6 +102,11 @@ sub data_number ($) {
     goto $class->can('new');
 }
 
+sub data_regexp ($) {
+    unshift @_, my $class = load 'Data::Object::Regexp';
+    goto $class->can('new');
+}
+
 sub data_scalar ($) {
     unshift @_, my $class = load 'Data::Object::Scalar';
     goto $class->can('new');
@@ -118,7 +117,7 @@ sub data_string ($) {
     goto $class->can('new');
 }
 
-sub data_undef ($) {
+sub data_undef (;$) {
     unshift @_, my $class = load 'Data::Object::Undef';
     goto $class->can('new');
 }
@@ -138,7 +137,7 @@ sub deduce ($) {
 
     # handle blessed objects
     elsif (blessed $scalar) {
-        return data_scalar $scalar if $scalar->isa('Regexp');
+        return data_regexp $scalar if $scalar->isa('Regexp');
         return $scalar;
     }
 
@@ -214,6 +213,7 @@ sub deduce_type ($) {
 
     return 'STRING'    if $object->isa('Data::Object::String');
     return 'SCALAR'    if $object->isa('Data::Object::Scalar');
+    return 'REGEXP'    if $object->isa('Data::Object::Regexp');
 
     return 'UNDEF'     if $object->isa('Data::Object::Undef');
     return 'UNIVERSAL' if $object->isa('Data::Object::Universal');
@@ -226,12 +226,11 @@ sub detract ($) {
     my $type   = deduce_type $object;
 
     INSPECT:
-    if (blessed($object) and ($object->isa('Regexp') or not $type)) {
-        return $object;
-    }
+    return $object unless $type;
 
     return [@$object] if $type eq 'ARRAY';
     return {%$object} if $type eq 'HASH';
+    return $$object   if $type eq 'REGEXP';
     return $$object   if $type eq 'FLOAT';
     return $$object   if $type eq 'NUMBER';
     return $$object   if $type eq 'INTEGER';
@@ -318,7 +317,7 @@ Data::Object - Data Type Objects for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -553,6 +552,10 @@ L<Data::Object::Number>
 
 =item *
 
+L<Data::Object::Regexp>
+
+=item *
+
 L<Data::Object::Scalar>
 
 =item *
