@@ -3,19 +3,14 @@ package Data::Object::Code;
 
 use 5.010;
 
-use Moo 'with';
-use Scalar::Util 'blessed';
-use Types::Standard 'CodeRef';
-
+use Carp         'confess';
 use Data::Object 'deduce_deep', 'detract_deep';
+use Moo          'with';
+use Scalar::Util 'blessed';
 
 with 'Data::Object::Role::Code';
-with 'Data::Object::Role::Defined';
-with 'Data::Object::Role::Detract';
-with 'Data::Object::Role::Output';
-with 'Data::Object::Role::Ref';
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 sub new {
     my $class = shift;
@@ -23,7 +18,8 @@ sub new {
 
     $class = ref($class) || $class;
     unless (blessed($data) && $data->isa($class)) {
-        $data = CodeRef->($data);
+        confess 'Type Instantiation Error: Not a CodeRef'
+            unless 'CODE' eq ref $data;
     }
 
     return bless $data, $class;
@@ -96,7 +92,7 @@ Data::Object::Code - A Code Object for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -109,21 +105,29 @@ version 0.13
 Data::Object::Code provides common methods for operating on Perl 5 code
 references. Code methods work on code references.
 
+=head1 COMPOSITION
+
+This class inherits all functionality from the L<Data::Object::Role::Code>
+role and implements proxy methods as documented herewith.
+
 =head1 CODIFICATION
 
 Certain methods provided by the this module support codification, a process
-which converts a string argument into code reference which can be used to supply
-a callback to the routine. A codified string can access its arguments by using
-variable names which correspond to letters in the alphabet which represent the
-position in the argument list. For example:
+which converts a string argument into a code reference which can be used to
+supply a callback to the method called. A codified string can access its
+arguments by using variable names which correspond to letters in the alphabet
+which represent the position in the argument list. For example:
 
-    $hash->method('$a + $b * $c', 100);
+    $array->example('$a + $b * $c', 100);
 
-    # given that $a and $b are method-supplied arguments
-    # ... whereas $c is assigned the user-supplied argument, 100
+    # if the example method does not supply any arguments automatically then
+    # the variable $a would be assigned the user-supplied value of 100,
+    # however, if the example method supplies two arguments automatically then
+    # those arugments would be assigned to the variables $a and $b whereas $c
+    # would be assigned the user-supplied value of 100
 
 Any place a codified string is accepted, a coderef or L<Data::Object::Code>
-is also valid.  Arguments are passed through the usual C<@_> list.
+object is also valid. Arguments are passed through the usual C<@_> list.
 
 =head1 METHODS
 
@@ -248,6 +252,10 @@ L<Data::Object::Number>
 
 =item *
 
+L<Data::Object::Regexp>
+
+=item *
+
 L<Data::Object::Scalar>
 
 =item *
