@@ -3,22 +3,14 @@ package Data::Object::Hash;
 
 use 5.010;
 
-use Moo 'with';
-use Scalar::Util 'blessed';
-use Types::Standard 'HashRef';
-
+use Carp         'confess';
 use Data::Object 'deduce_deep', 'detract_deep';
+use Moo          'with';
+use Scalar::Util 'blessed';
 
 with 'Data::Object::Role::Hash';
-with 'Data::Object::Role::Defined';
-with 'Data::Object::Role::Collection';
-with 'Data::Object::Role::Detract';
-with 'Data::Object::Role::Keyed';
-with 'Data::Object::Role::Output';
-with 'Data::Object::Role::Ref';
-with 'Data::Object::Role::Values';
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 sub new {
     my $class = shift;
@@ -26,7 +18,8 @@ sub new {
 
     $class = ref($class) || $class;
     unless (blessed($data) && $data->isa($class)) {
-        $data = HashRef->($data);
+        confess 'Type Instantiation Error: Not a HashRef'
+            unless 'HASH' eq ref $data;
     }
 
     return bless $data, $class;
@@ -220,7 +213,7 @@ Data::Object::Hash - A Hash Object for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -237,21 +230,29 @@ returning a new array reference. Unless stated, it may be safe to assume that
 the following methods copy, modify and return new hash references based on their
 function.
 
+=head1 COMPOSITION
+
+This class inherits all functionality from the L<Data::Object::Role::Hash>
+role and implements proxy methods as documented herewith.
+
 =head1 CODIFICATION
 
 Certain methods provided by the this module support codification, a process
-which converts a string argument into code reference which can be used to supply
-a callback to the routine. A codified string can access its arguments by using
-variable names which correspond to letters in the alphabet which represent the
-position in the argument list. For example:
+which converts a string argument into a code reference which can be used to
+supply a callback to the method called. A codified string can access its
+arguments by using variable names which correspond to letters in the alphabet
+which represent the position in the argument list. For example:
 
-    $hash->method('$a + $b * $c', 100);
+    $array->example('$a + $b * $c', 100);
 
-    # given that $a and $b are method-supplied arguments
-    # ... whereas $c is assigned the user-supplied argument, 100
+    # if the example method does not supply any arguments automatically then
+    # the variable $a would be assigned the user-supplied value of 100,
+    # however, if the example method supplies two arguments automatically then
+    # those arugments would be assigned to the variables $a and $b whereas $c
+    # would be assigned the user-supplied value of 100
 
 Any place a codified string is accepted, a coderef or L<Data::Object::Code>
-is also valid.  Arguments are passed through the usual C<@_> list.
+object is also valid. Arguments are passed through the usual C<@_> list.
 
 =head1 METHODS
 
@@ -493,7 +494,7 @@ execution.
 
     $hash->merge({7,7,9,9}); # {1=>2,3=>4,5=>6,7=>7,9=>9}
 
-The list method returns a hash reference where the elements in the hash and
+The merge method returns a hash reference where the elements in the hash and
 the elements in the argument(s) are merged. This operation performs a deep merge
 and clones the datasets to ensure no side-effects. This method returns a
 L<Data::Object::Hash> object.
@@ -591,6 +592,10 @@ L<Data::Object::Number>
 
 =item *
 
+L<Data::Object::Regexp>
+
+=item *
+
 L<Data::Object::Scalar>
 
 =item *
