@@ -3,26 +3,21 @@ package Data::Object::Number;
 
 use 5.010;
 
-use Moo 'with';
-use Scalar::Util 'blessed';
-use Types::Standard 'Num';
-
+use Carp         'confess';
 use Data::Object 'deduce_deep', 'detract_deep';
+use Moo          'with';
+use Scalar::Util 'blessed', 'looks_like_number';
 
 with 'Data::Object::Role::Number';
-with 'Data::Object::Role::Defined';
-with 'Data::Object::Role::Detract';
-with 'Data::Object::Role::Numeric';
-with 'Data::Object::Role::Output';
 
-use overload
-    'bool'   => \&data,
-    '""'     => \&data,
-    '~~'     => \&data,
+use overload (
+    'bool'   => 'data',
+    '""'     => 'data',
+    '~~'     => 'data',
     fallback => 1,
-;
+);
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 sub new {
     my $class = shift;
@@ -32,7 +27,9 @@ sub new {
 
     $class = ref($class) || $class;
     unless (blessed($data) && $data->isa($class)) {
-        $data = Num->($data);
+        confess 'Type Instantiation Error: Not a Number'
+            unless defined($data) && !ref($data)
+            && looks_like_number($data);
     }
 
     return bless \$data, $class;
@@ -198,7 +195,7 @@ Data::Object::Number - A Number Object for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -216,6 +213,11 @@ methods that modify the number itself as opposed to returning a new number.
 Unless stated, it may be safe to assume that the following methods copy, modify
 and return new numbers based on their function.
 
+=head1 COMPOSITION
+
+This class inherits all functionality from the L<Data::Object::Role::Number>
+role and implements proxy methods as documented herewith.
+
 =head1 METHODS
 
 =head2 abs
@@ -224,7 +226,8 @@ and return new numbers based on their function.
 
     $number->abs; # 12
 
-    $number = -12;
+    # given -12
+
     $number->abs; # 12
 
 The abs method returns the absolute value of the number. This method returns a
@@ -257,21 +260,60 @@ method returns a L<Data::Object::Float> object.
 The decr method returns the numeric number decremented by 1. This method returns
 a data type object to be determined after execution.
 
+=head2 downto
+
+    # given 10
+
+    $number->downto(5); # [10,9,8,7,6,5]
+
+The downto method returns an array reference containing integer decreasing
+values down to and including the limit. This method returns a
+L<Data::Object::Array> object.
+
+=head2 eq
+
+    # given 12345
+
+    $number->eq(12346); # 0
+
+The eq method performs a numeric equality operation. This method returns a
+L<Data::Object::Number> object representing a boolean.
+
 =head2 exp
 
     # given 0
 
     $number->exp; # 1
 
-    $number = 1;
+    # given 1
+
     $number->exp; # 2.71828182845905
 
-    $number = 1.5;
+    # given 1.5
+
     $number->exp; # 4.48168907033806
 
 The exp method returns e (the natural logarithm base) to the power of the
 number. This method returns a L<Data::Object::Float> object.
 
+=head2 gt
+
+    # given 99
+
+    $number->gt(50); # 1
+
+The gt method performs a numeric greater-than comparison. This method returns a
+L<Data::Object::Number> object representing a boolean.
+
+=head2 gte
+
+    # given 100
+
+    $number->gte(100); # 1
+
+The gte method performs a numeric greater-than-or-equal-to comparison. This
+method returns a L<Data::Object::Number> object representing a boolean.
+
 =head2 hex
 
     # given 175
@@ -308,6 +350,24 @@ method for rounding. This method returns a L<Data::Object::Number> object.
 The log method returns the natural logarithm (base e) of the number. This method
 returns a L<Data::Object::Float> object.
 
+=head2 lt
+
+    # given 86
+
+    $number->lt(88); # 1
+
+The lt method performs a numeric less-than comparison. This method returns a
+L<Data::Object::Number> object representing a boolean.
+
+=head2 lte
+
+    # given 50
+
+    $number->lte(50); # 1
+
+The lte method performs a numeric less-than-or-equal-to comparison. This
+method returns a L<Data::Object::Number> object representing a boolean.
+
 =head2 mod
 
     # given 12
@@ -321,6 +381,15 @@ returns a L<Data::Object::Float> object.
 The mod method returns the division remainder of the number divided by the
 argment. This method returns a L<Data::Object::Number> object.
 
+=head2 ne
+
+    # given -100
+
+    $number->ne(100); # 1
+
+The ne method performs a numeric equality operation. This method returns a
+L<Data::Object::Number> object representing a boolean.
+
 =head2 neg
 
     # given 12345
@@ -358,6 +427,56 @@ method returns a data type object to be determined after execution.
 The sqrt method returns the positive square root of the number. This method
 returns a data type object to be determined after execution.
 
+=head2 to
+
+    # given 5
+
+    $number->to(9); # [5,6,7,8,9]
+    $number->to(1); # [5,4,3,2,1]
+
+The to method returns an array reference containing integer increasing or
+decreasing values to and including the limit in ascending or descending order
+based on the value of the floating-point object. This method returns a
+L<Data::Object::Array> object.
+
+=head2 upto
+
+    # given 23
+
+    $number->upto(25); # [23,24,25]
+
+The upto method returns an array reference containing integer increasing
+values up to and including the limit. This method returns a
+L<Data::Object::Array> object.
+
+=head1 OPERATORS
+
+This class overloads the following operators for your convenience.
+
+=head2 bool
+
+    !!$number
+
+    # equivilent to
+
+    $number->data
+
+=head2 smartmatch
+
+    $value ~~ $number
+
+    # equivilent to
+
+    $number->data
+
+=operation string
+
+    "$number"
+
+    # equivilent to
+
+    $number->data
+
 =head1 SEE ALSO
 
 =over 4
@@ -388,6 +507,10 @@ L<Data::Object::Number>
 
 =item *
 
+L<Data::Object::Regexp>
+
+=item *
+
 L<Data::Object::Scalar>
 
 =item *
