@@ -7,7 +7,18 @@ use Moo::Role;
 use Data::Object 'codify';
 use Scalar::Util 'looks_like_number';
 
-our $VERSION = '0.13'; # VERSION
+map with($_), our @ROLES = qw(
+    Data::Object::Role::Defined
+    Data::Object::Role::Collection
+    Data::Object::Role::Detract
+    Data::Object::Role::Indexed
+    Data::Object::Role::List
+    Data::Object::Role::Output
+    Data::Object::Role::Ref
+    Data::Object::Role::Values
+);
+
+our $VERSION = '0.14'; # VERSION
 
 sub all {
     my ($array, $code, @arguments) = @_;
@@ -360,7 +371,7 @@ Data::Object::Role::Array - An Array Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -371,6 +382,46 @@ version 0.13
 Data::Object::Role::Array provides functions for operating on Perl 5 array
 references.
 
+=head1 ROLES
+
+This role is composed of the following roles.
+
+=over 4
+
+=item *
+
+L<Data::Object::Role::Collection>
+
+=item *
+
+L<Data::Object::Role::Defined>
+
+=item *
+
+L<Data::Object::Role::Detract>
+
+=item *
+
+L<Data::Object::Role::Indexed>
+
+=item *
+
+L<Data::Object::Role::List>
+
+=item *
+
+L<Data::Object::Role::Output>
+
+=item *
+
+L<Data::Object::Role::Ref>
+
+=item *
+
+L<Data::Object::Role::Values>
+
+=back
+
 =head1 SEE ALSO
 
 =over 4
@@ -401,6 +452,10 @@ L<Data::Object::Role::Number>
 
 =item *
 
+L<Data::Object::Role::Regexp>
+
+=item *
+
 L<Data::Object::Role::Scalar>
 
 =item *
