@@ -6,7 +6,14 @@ use Moo::Role;
 
 use Data::Object 'codify';
 
-our $VERSION = '0.13'; # VERSION
+map with($_), our @ROLES = qw(
+    Data::Object::Role::Defined
+    Data::Object::Role::Detract
+    Data::Object::Role::Output
+    Data::Object::Role::Ref
+);
+
+our $VERSION = '0.14'; # VERSION
 
 sub call {
     my ($code, @arguments) = @_;
@@ -59,7 +66,7 @@ Data::Object::Role::Code - A Code Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -70,6 +77,30 @@ version 0.13
 Data::Object::Role::Code provides functions for operating on Perl 5 code
 references.
 
+=head1 ROLES
+
+This role is composed of the following roles.
+
+=over 4
+
+=item *
+
+L<Data::Object::Role::Defined>
+
+=item *
+
+L<Data::Object::Role::Detract>
+
+=item *
+
+L<Data::Object::Role::Output>
+
+=item *
+
+L<Data::Object::Role::Ref>
+
+=back
+
 =head1 SEE ALSO
 
 =over 4
@@ -100,6 +131,10 @@ L<Data::Object::Role::Number>
 
 =item *
 
+L<Data::Object::Role::Regexp>
+
+=item *
+
 L<Data::Object::Role::Scalar>
 
 =item *
