@@ -5,19 +5,14 @@ use 5.010;
 use Moo::Role;
 
 use Scalar::Util 'blessed';
-use Types::Standard 'Any';
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 sub new {
     my $class = shift;
     my $data  = shift;
 
     $class = ref($class) || $class;
-    unless (blessed($data) && $data->isa($class)) {
-        $data = Any->($data);
-    }
-
     if (blessed($data) && $data->isa('Regexp') && $^V <= v5.12.0) {
         $data = do {\(my $q = qr/$data/)};
     }
