@@ -4,7 +4,14 @@ package Data::Object::Role::Float;
 use 5.010;
 use Moo::Role;
 
-our $VERSION = '0.13'; # VERSION
+map with($_), our @ROLES = qw(
+    Data::Object::Role::Defined
+    Data::Object::Role::Detract
+    Data::Object::Role::Numeric
+    Data::Object::Role::Output
+);
+
+our $VERSION = '0.14'; # VERSION
 
 1;
 
@@ -20,7 +27,7 @@ Data::Object::Role::Float - A Float Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -31,6 +38,30 @@ version 0.13
 Data::Object::Role::Float provides functions for operating on Perl 5
 floating-point data.
 
+=head1 ROLES
+
+This role is composed of the following roles.
+
+=over 4
+
+=item *
+
+L<Data::Object::Role::Defined>
+
+=item *
+
+L<Data::Object::Role::Detract>
+
+=item *
+
+L<Data::Object::Role::Numeric>
+
+=item *
+
+L<Data::Object::Role::Output>
+
+=back
+
 =head1 SEE ALSO
 
 =over 4
@@ -61,6 +92,10 @@ L<Data::Object::Role::Number>
 
 =item *
 
+L<Data::Object::Role::Regexp>
+
+=item *
+
 L<Data::Object::Role::Scalar>
 
 =item *
