@@ -4,11 +4,21 @@ package Data::Object::Role::Hash;
 use 5.010;
 use Moo::Role;
 
-use Clone 'clone';
 use Data::Object 'codify';
 use Scalar::Util 'blessed';
+use Storable     'dclone';
 
-our $VERSION = '0.13'; # VERSION
+map with($_), our @ROLES = qw(
+    Data::Object::Role::Defined
+    Data::Object::Role::Collection
+    Data::Object::Role::Detract
+    Data::Object::Role::Keyed
+    Data::Object::Role::Output
+    Data::Object::Role::Ref
+    Data::Object::Role::Values
+);
+
+our $VERSION = '0.14'; # VERSION
 
 sub aslice {
     goto &array_slice;
@@ -182,8 +192,8 @@ sub pairs_array {
 sub merge {
     my ($hash, @arguments) = @_;
 
-    return clone $hash unless @arguments;
-    return clone merge($hash, merge(@arguments)) if @arguments > 1;
+    return dclone $hash unless @arguments;
+    return dclone merge($hash, merge(@arguments)) if @arguments > 1;
 
     my ($right) = @arguments;
 
@@ -194,7 +204,7 @@ sub merge {
         else { $merge{$key} = $right->{$key} }
     }
 
-    return clone \%merge;
+    return dclone \%merge;
 }
 
 sub reset {
@@ -238,7 +248,7 @@ Data::Object::Role::Hash - A Hash Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -249,6 +259,42 @@ version 0.13
 Data::Object::Role::Hash provides functions for operating on Perl 5 hash
 references.
 
+=head1 ROLES
+
+This role is composed of the following roles.
+
+=over 4
+
+=item *
+
+L<Data::Object::Role::Collection>
+
+=item *
+
+L<Data::Object::Role::Defined>
+
+=item *
+
+L<Data::Object::Role::Detract>
+
+=item *
+
+L<Data::Object::Role::Keyed>
+
+=item *
+
+L<Data::Object::Role::Output>
+
+=item *
+
+L<Data::Object::Role::Ref>
+
+=item *
+
+L<Data::Object::Role::Values>
+
+=back
+
 =head1 SEE ALSO
 
 =over 4
@@ -279,6 +325,10 @@ L<Data::Object::Role::Number>
 
 =item *
 
+L<Data::Object::Role::Regexp>
+
+=item *
+
 L<Data::Object::Role::Scalar>
 
 =item *
