@@ -3,13 +3,14 @@ package Data::Object::Role::Output;
 
 use 5.010;
 use Moo::Role;
-use Data::Dumper ();
 
 use Data::Object 'detract_deep';
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 sub dump {
+    require Data::Dumper;
+
     local $Data::Dumper::Indent    = 0;
     local $Data::Dumper::Purity    = 0;
     local $Data::Dumper::Quotekeys = 0;
