@@ -4,7 +4,13 @@ package Data::Object::Role::String;
 use 5.010;
 use Moo::Role;
 
-our $VERSION = '0.13'; # VERSION
+map with($_), our @ROLES = qw(
+    Data::Object::Role::Defined
+    Data::Object::Role::Detract
+    Data::Object::Role::Output
+);
+
+our $VERSION = '0.14'; # VERSION
 
 sub append {
     return join ' ', @_;
@@ -165,7 +171,7 @@ Data::Object::Role::String - A String Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -176,6 +182,26 @@ version 0.13
 Data::Object::Role::String provides functions for operating on Perl 5 string
 data.
 
+=head1 ROLES
+
+This role is composed of the following roles.
+
+=over 4
+
+=item *
+
+L<Data::Object::Role::Defined>
+
+=item *
+
+L<Data::Object::Role::Detract>
+
+=item *
+
+L<Data::Object::Role::Output>
+
+=back
+
 =head1 SEE ALSO
 
 =over 4
