@@ -4,7 +4,12 @@ package Data::Object::Role::Undef;
 use 5.010;
 use Moo::Role;
 
-our $VERSION = '0.13'; # VERSION
+map with($_), our @ROLES = qw(
+    Data::Object::Role::Detract
+    Data::Object::Role::Output
+);
+
+our $VERSION = '0.14'; # VERSION
 
 sub defined {
     return 0;
@@ -24,7 +29,7 @@ Data::Object::Role::Undef - An Undef Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -35,6 +40,22 @@ version 0.13
 Data::Object::Role::Undef provides functions  for operating on Perl 5 undefined
 data.
 
+=head1 ROLES
+
+This role is composed of the following roles.
+
+=over 4
+
+=item *
+
+L<Data::Object::Role::Detract>
+
+=item *
+
+L<Data::Object::Role::Output>
+
+=back
+
 =head1 SEE ALSO
 
 =over 4
@@ -65,6 +86,10 @@ L<Data::Object::Role::Number>
 
 =item *
 
+L<Data::Object::Role::Regexp>
+
+=item *
+
 L<Data::Object::Role::Scalar>
 
 =item *
