@@ -4,7 +4,15 @@ package Data::Object::Role::Universal;
 use 5.010;
 use Moo::Role;
 
-our $VERSION = '0.13'; # VERSION
+map with($_), our @ROLES = qw(
+    Data::Object::Role::Constructor
+    Data::Object::Role::Defined
+    Data::Object::Role::Detract
+    Data::Object::Role::Output
+    Data::Object::Role::Ref
+);
+
+our $VERSION = '0.14'; # VERSION
 
 1;
 
@@ -20,7 +28,7 @@ Data::Object::Role::Universal - A Universal Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -31,6 +39,34 @@ version 0.13
 Data::Object::Role::Universal provides functions for operating on any Perl 5 data
 types.
 
+=head1 ROLES
+
+This role is composed of the following roles.
+
+=over 4
+
+=item *
+
+L<Data::Object::Role::Constructor>
+
+=item *
+
+L<Data::Object::Role::Defined>
+
+=item *
+
+L<Data::Object::Role::Detract>
+
+=item *
+
+L<Data::Object::Role::Output>
+
+=item *
+
+L<Data::Object::Role::Ref>
+
+=back
+
 =head1 SEE ALSO
 
 =over 4
@@ -61,6 +97,10 @@ L<Data::Object::Role::Number>
 
 =item *
 
+L<Data::Object::Role::Regexp>
+
+=item *
+
 L<Data::Object::Role::Scalar>
 
 =item *
