@@ -3,25 +3,21 @@ package Data::Object::String;
 
 use 5.010;
 
-use Moo 'with';
-use Scalar::Util 'blessed';
-use Types::Standard 'Str';
-
+use Carp         'confess';
 use Data::Object 'deduce_deep', 'detract_deep';
+use Moo          'with';
+use Scalar::Util 'blessed';
 
 with 'Data::Object::Role::String';
-with 'Data::Object::Role::Defined';
-with 'Data::Object::Role::Detract';
-with 'Data::Object::Role::Output';
 
-use overload
-    'bool'   => \&data,
-    '""'     => \&data,
-    '~~'     => \&data,
+use overload (
+    'bool'   => 'data',
+    '""'     => 'data',
+    '~~'     => 'data',
     fallback => 1,
-;
+);
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 sub new {
     my $class = shift;
@@ -29,7 +25,8 @@ sub new {
 
     $class = ref($class) || $class;
     unless (blessed($data) && $data->isa($class)) {
-        $data = Str->($data);
+        confess 'Type Instantiation Error: Not a String'
+            unless defined($data) && not ref($data);
     }
 
     return bless \$data, $class;
@@ -207,7 +204,7 @@ Data::Object::String - A String Object for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -225,6 +222,11 @@ modify the string itself as opposed to returning a new string. Unless stated, it
 may be safe to assume that the following methods copy, modify and return new
 strings based on their function.
 
+=head1 COMPOSITION
+
+This class inherits all functionality from the L<Data::Object::Role::String>
+role and implements proxy methods as documented herewith.
+
 =head1 METHODS
 
 =head2 append
@@ -513,6 +515,34 @@ The words method splits the string into a list of strings, separating each
 group of characters by 1 or more consecutive spaces, and returns that list as an
 array reference. This method returns a L<Data::Object::Array> object.
 
+=head1 OPERATORS
+
+This class overloads the following operators for your convenience.
+
+=head2 bool
+
+    !!$string
+
+    # equivilent to
+
+    $string->data
+
+=head2 smartmatch
+
+    $value ~~ $string
+
+    # equivilent to
+
+    $string->data
+
+=operation string
+
+    "$string"
+
+    # equivilent to
+
+    $string->data
+
 =head1 SEE ALSO
 
 =over 4
@@ -543,6 +573,10 @@ L<Data::Object::Number>
 
 =item *
 
+L<Data::Object::Regexp>
+
+=item *
+
 L<Data::Object::Scalar>
 
 =item *
