@@ -3,24 +3,21 @@ package Data::Object::Undef;
 
 use 5.010;
 
-use Moo 'with';
-use Scalar::Util 'blessed';
-use Types::Standard 'Undef';
-
+use Carp         'confess';
 use Data::Object 'deduce_deep', 'detract_deep';
+use Moo          'with';
+use Scalar::Util 'blessed';
 
 with 'Data::Object::Role::Undef';
-with 'Data::Object::Role::Detract';
-with 'Data::Object::Role::Output';
 
-use overload
-    'bool'   => \&data,
-    '""'     => \&data,
-    '~~'     => \&data,
+use overload (
+    'bool'   => 'data',
+    '""'     => 'data',
+    '~~'     => 'data',
     fallback => 1,
-;
+);
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 sub new {
     my $class = shift;
@@ -28,7 +25,8 @@ sub new {
 
     $class = ref($class) || $class;
     unless (blessed($data) && $data->isa($class)) {
-        $data = Undef->($data);
+        confess 'Type Instantiation Error: Not an Undefined value'
+            if defined $data;
     }
 
     return bless \$data, $class;
@@ -62,7 +60,7 @@ Data::Object::Undef - An Undef Object for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -75,6 +73,11 @@ version 0.13
 Data::Object::Undef provides common methods for operating on Perl 5 undefined
 data. Undef methods work on undefined values.
 
+=head1 COMPOSITION
+
+This class inherits all functionality from the L<Data::Object::Role::Undef>
+role and implements proxy methods as documented herewith.
+
 =head1 METHODS
 
 =head2 defined
@@ -86,6 +89,34 @@ data. Undef methods work on undefined values.
 The defined method always returns false. This method returns a
 L<Data::Object::Number> object.
 
+=head1 OPERATORS
+
+This class overloads the following operators for your convenience.
+
+=head2 bool
+
+    !!$undef
+
+    # equivilent to
+
+    $undef->data
+
+=head2 smartmatch
+
+    $value ~~ $undef
+
+    # equivilent to
+
+    $undef->data
+
+=operation string
+
+    "$undef"
+
+    # equivilent to
+
+    $undef->data
+
 =head1 SEE ALSO
 
 =over 4
@@ -116,6 +147,10 @@ L<Data::Object::Number>
 
 =item *
 
+L<Data::Object::Regexp>
+
+=item *
+
 L<Data::Object::Scalar>
 
 =item *
