@@ -3,17 +3,14 @@ package Data::Object::Universal;
 
 use 5.010;
 
-use Moo 'with';
-use Data::Object 'detract_deep';
+use Carp         'confess';
+use Data::Object 'deduce_deep', 'detract_deep';
+use Moo          'with';
+use Scalar::Util 'blessed';
 
-with 'Data::Object::Role::Constructor';
 with 'Data::Object::Role::Universal';
-with 'Data::Object::Role::Defined';
-with 'Data::Object::Role::Detract';
-with 'Data::Object::Role::Output';
-with 'Data::Object::Role::Ref';
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 sub data {
     goto &detract;
@@ -37,7 +34,7 @@ Data::Object::Universal - A Universal Object for Perl 5
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -50,6 +47,11 @@ version 0.13
 Data::Object::Universal provides common methods for operating on any Perl 5 data
 types.
 
+=head1 COMPOSITION
+
+This class inherits all functionality from the L<Data::Object::Role::Universal>
+role and implements proxy methods as documented herewith.
+
 =head1 SEE ALSO
 
 =over 4
@@ -80,6 +82,10 @@ L<Data::Object::Number>
 
 =item *
 
+L<Data::Object::Regexp>
+
+=item *
+
 L<Data::Object::Scalar>
 
 =item *
